==> activity-center-api-0.12.47-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/req/PageQueryLandReq.java <==
package cn.com.duiba.tuia.activity.center.api.dto.req;

import java.util.List;

/**
 * Created by MichealWang on 2018/9/27 0027.
 */
public class PageQueryLandReq extends ReqPageQuery {

    /**
     * 查询开始时间 yyyy-MM-dd
     */
    private String startDate;
    /**
     * 查询结束时间 yyyy-MM-dd
     */
    private String endDate;
    /**
     * 落地页id
     */
    private Long landId;
    /**
     * 落地页关联行业id
     */
    private Long advertTradId;
    /**
     * 落地页名称
     */
    private String title;

    /**
     * 当前用户类型 null表示可以查询所有 落地页
     * 0：来自广告管理平台，1：来自代理商平台 2:来自JF建站平台
     * @see cn.com.duiba.tuia.activity.center.api.constant.LandPageSource
     */
    private Integer source;

    /**
     * 当前用户id
     */
    private Long ssoAeId;
    /**
     * 积木落地页标签
     */
    private String promoteTag;

    private List<Long> ids;

    /** 是否共享 0:否 1:是 */
    private Boolean isShared;

    /** 广告主账户ID */
    private Long accountId;

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Long getLandId() {
        return landId;
    }

    public void setLandId(Long landId) {
        this.landId = landId;
    }

    public Long getAdvertTradId() {
        return advertTradId;
    }

    public void setAdvertTradId(Long advertTradId) {
        this.advertTradId = advertTradId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }

    public Long getSsoAeId() {
        return ssoAeId;
    }

    public void setSsoAeId(Long ssoAeId) {
        this.ssoAeId = ssoAeId;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Boolean getIsShared() {
        return isShared;
    }

    public void setIsShared(Boolean isShared) {
        this.isShared = isShared;
    }
}

==> activity-center-api-0.16.46-20230831.074244-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/req/PageQueryLandReq.java <==
package cn.com.duiba.tuia.activity.center.api.dto.req;

import java.util.List;

/**
 * Created by MichealWang on 2018/9/27 0027.
 */
public class PageQueryLandReq extends ReqPageQuery {

    /**
     * 查询开始时间 yyyy-MM-dd
     */
    private String startDate;
    /**
     * 查询结束时间 yyyy-MM-dd
     */
    private String endDate;
    /**
     * 落地页id
     */
    private Long landId;
    /**
     * 落地页关联行业id
     */
    private Long advertTradId;
    /**
     * 落地页名称
     */
    private String title;

    /**
     * 当前用户类型 null表示可以查询所有 落地页
     * 0：来自广告管理平台，1：来自代理商平台 2:来自JF建站平台
     * @see cn.com.duiba.tuia.activity.center.api.constant.LandPageSource
     */
    private Integer source;

    /**
     * 当前用户id
     */
    private Long ssoAeId;
    /**
     * 积木落地页标签
     */
    private String promoteTag;

    private List<Long> ids;

    /** 是否共享 0:否 1:是 */
    private Boolean isShared;

    /** 广告主账户ID */
    private Long accountId;

    /**
     * 模版ID
     */
    private Long templateId;

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public Long getLandId() {
        return landId;
    }

    public void setLandId(Long landId) {
        this.landId = landId;
    }

    public Long getAdvertTradId() {
        return advertTradId;
    }

    public void setAdvertTradId(Long advertTradId) {
        this.advertTradId = advertTradId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }

    public Long getSsoAeId() {
        return ssoAeId;
    }

    public void setSsoAeId(Long ssoAeId) {
        this.ssoAeId = ssoAeId;
    }

    public String getPromoteTag() {
        return promoteTag;
    }

    public void setPromoteTag(String promoteTag) {
        this.promoteTag = promoteTag;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Boolean getIsShared() {
        return isShared;
    }

    public void setIsShared(Boolean isShared) {
        this.isShared = isShared;
    }

    public Long getTemplateId() {
        return templateId;
    }

    public void setTemplateId(Long templateId) {
        this.templateId = templateId;
    }
}
